__version__ = "0.5.6"
from .bins import *
from .perf import *
from .stats import *
from .utils import *
from .props import *
from .logit import *
from .regression import *
from .basics import *
from .visualize import *
from .notebook import *
from .example_data import *
